@@ -7,7 +7,7 @@
 # dlu
 #
 
-mgroup <- function(edist, groups, nperm=1000)  
+mgroup <- function(edist, groups, nperm = 1000, mrank = FALSE)  
 {
     nl <- ncol(groups)
     if(is.null(nl)) {
@@ -15,6 +15,10 @@ mgroup <- function(edist, groups, nperm=1000)
         nl <- 1
     }
 
+    if(mrank) {
+        edist <- rank(edist)
+    }
+
     outtable <- data.frame(nclust = rep(NA, nl), mantelr = rep(NA, nl), pval = rep(NA, nl))
 
     for (i in seq_len(nl)) {
